@import 'mixins.styl'

names = a b c d e f g h i j k l m n o
colors = #f05b4f #2196f3 #4caf50 #ffc107 #673ab7 #03a9f4 #8bc34a #ff9800 #e91e63 #3f51b5 #009688 #cddc39 #795548 #9c27b0 #00bcd4

chartist-colors(names, colors)