$font-size = 12px
$line-height = 1.4
$line-$height-computed = ceil($font-size * $line-height)
$text-color = #333
$border-radius = 3px
$block-gap-x = 20px
$block-gap-y = $block-gap-x

$axis-x = 14px
$axis-y = ($axis-x / 2)

$screen-xs = 320px
$screen-sm = 768px
$screen-md = 1000px
